Module calendar

Module calendar 

Structs

CalendarPeriod
A named display period for CalendarPlot.
CalendarPlot
GitHub-style calendar heatmap.

Enums

CalendarAgg
Aggregation function for multiple values on the same day.
WeekStart
Which day starts the week row in the calendar grid.